@@ -67,6 +67,12 @@ void        gs_manager_get_lock_active      (GSManager  *manager,
                                              gboolean   *lock_active);
 void        gs_manager_set_lock_active      (GSManager  *manager,
                                              gboolean    lock_active);
+void        gs_manager_set_keyboard_enabled (GSManager  *manager,
+                                             gboolean    enabled);
+void        gs_manager_set_keyboard_command (GSManager  *manager,
+                                             const char *command);
+void        gs_manager_get_lock_enabled     (GSManager  *manager,
+                                             gboolean   *lock_enabled);
 void        gs_manager_set_lock_enabled     (GSManager  *manager,
                                              gboolean    lock_enabled);
 void        gs_manager_set_lock_timeout     (GSManager  *manager,
@@ -88,6 +94,7 @@ void        gs_manager_set_themes           (GSManager  *manager,
 void        gs_manager_set_mode             (GSManager  *manager,
                                              GSSaverMode mode);
 gboolean    gs_manager_request_unlock       (GSManager  *manager);
+void        gs_manager_cancel_unlock_request (GSManager *manager);
 
 G_END_DECLS
 
